@@ -33,6 +33,7 @@ class Core:
         AGENT_NAME: str | None = None, 
         CORE_API: str = None, 
         JWT_TOKEN: str | None = None,
+        AGENT_DISPLAY_NAME: str = None
     ):
         """
         Initialize Core API handler with agent credentials and base API URL.
@@ -56,7 +57,7 @@ class Core:
         self.AGENT_NAME = AGENT_NAME
         self.JWT_TOKEN = JWT_TOKEN
         self._PASSWORD: str = None  # Store password for future use
-        self.USER_INFO: dict = {}
+        self.AGENT_DISPLAY_NAME: str = AGENT_DISPLAY_NAME
         self.RUNTIME_VARIABLES: dict[str, str | None] = {}
     
     def is_token_valid(self) -> bool:
@@ -94,6 +95,7 @@ class Core:
         agent_name = os.environ.get("AGENT_NAME")
         core_api = os.environ.get("CORE_API")
         jwt_token = os.environ.get("AGENTIX_CORE_JWT_TOKEN")
+        agent_display_name = os.environ.get("AGENT_DISPLAY_NAME")
         password = os.environ.get("CORE_PASSWORD")
 
         print("📜 Initializing Core from environment variables ... ")
@@ -113,6 +115,7 @@ class Core:
             AGENT_NAME=agent_name,
             CORE_API=core_api,
             JWT_TOKEN=jwt_token,
+            AGENT_DISPLAY_NAME=agent_display_name
         )
         core._PASSWORD = password
         return core
@@ -229,9 +232,11 @@ class Core:
                         if login_response.status == 200 and "jwt" in login_json:
                             self.JWT_TOKEN = login_json["jwt"]
                             self._PASSWORD = PASSWORD  # Store password for future use
-                            self.USER_INFO = login_json.get("user", {})
+                            self.AGENT_DISPLAY_NAME = f"{login_json.get('user', {}).get('firstName', '') or ''} {login_json.get('user', {}).get('lastName', '') or ''}".strip()
                             os.environ["AGENTIX_CORE_JWT_TOKEN"] = self.JWT_TOKEN
-                            logger.info(f"✅ [LOGIN] Login succeeded on attempt {attempt}")                            
+                            os.environ["AGENT_DISPLAY_NAME"] = self.AGENT_DISPLAY_NAME
+
+                            logger.info(f"✅ [LOGIN] Login succeeded on attempt {attempt}")
                             break
                         else:
                             logger.warning(f"⚠️ [LOGIN] Login failed on attempt {attempt}: {login_response.status} - {login_json}")
